==============================================
Essential Classes in sympy.vector (docstrings)
==============================================


.. autoclass:: sympy.vector.coordsysrect.CoordSys3D
   :members:

   .. automethod:: sympy.vector.coordsysrect.CoordSys3D.__init__

.. autoclass:: sympy.vector.vector.Vector
   :members:

.. autoclass:: sympy.vector.dyadic.Dyadic
   :members:

.. autoclass:: sympy.vector.deloperator.Del
   :members:

.. autoclass:: sympy.vector.parametricregion.ParametricRegion
   :members:

.. autoclass:: sympy.vector.implicitregion.ImplicitRegion
   :members:

.. autoclass:: sympy.vector.integrals.ParametricIntegral
   :members:
